@@ -1,20 +1,11 @@
-/*!
- * fill-range <https://github.com/jonschlinkert/fill-range>
- *
- * Copyright (c) 2014-2017, Jon Schlinkert.
- * Released under the MIT License.
- */
-
 'use strict';
 
-require('mocha');
-var assert = require('assert');
-var exact = require('./support/exact');
-var fill = require('..');
+const exact = require('./support/exact');
+const fill = require('..');
 
-describe('special cases', function() {
-  describe('negative zero', function() {
-    it('should handle negative zero', function() {
+describe('special cases', () => {
+  describe('negative zero', () => {
+    it('should handle negative zero', () => {
       exact(fill('-5', '-0', '-1'), ['-5', '-4', '-3', '-2', '-1', '0']);
       exact(fill('1', '-0', 1), ['1', '0']);
       exact(fill('1', '-0', 0), ['1', '0']);
@@ -29,8 +20,8 @@ describe('special cases', function() {
       exact(fill(0, 5, 2), [0, 2, 4]);
     });
 
-    it('should adjust padding for negative numbers:', function() {
-      exact(fill('-01', '5'), ['-01','000','001','002','003','004','005']);
+    it('should adjust padding for negative numbers:', () => {
+      exact(fill('-01', '5'), ['-01', '000', '001', '002', '003', '004', '005']);
     });
   });
 });
